import os
import unittest

import stadiamaps


class TestEUEndpoint(unittest.TestCase):
    def setUp(self):
        self.configuration = stadiamaps.Configuration(host="https://api-eu.stadiamaps.com")
        self.configuration.api_key["ApiKeyAuth"] = os.environ["STADIA_API_KEY"]

    def tearDown(self):
        pass

    def testAutocomplete(self):
        with stadiamaps.ApiClient(self.configuration) as api_client:
            api_instance = stadiamaps.GeocodingApi(api_client)

            res = api_instance.autocomplete("Põhja pst 27a")
            self.assertEqual("Estonia", res.features[0].properties.country)
            self.assertEqual("address", res.features[0].properties.layer)



# flake8: noqa

# import apis into api package
from stadiamaps.api.geocoding_api import GeocodingApi
from stadiamaps.api.geospatial_api import GeospatialApi
from stadiamaps.api.routing_api import RoutingApi




# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.1
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import stadiamaps
from stadiamaps.models.route_maneuver import RouteManeuver  # noqa: E501
from stadiamaps.rest import ApiException

class TestRouteManeuver(unittest.TestCase):
    """RouteManeuver unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test RouteManeuver
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RouteManeuver`
        """
        model = stadiamaps.models.route_maneuver.RouteManeuver()  # noqa: E501
        if include_optional :
            return RouteManeuver(
                type = 56, 
                instruction = '', 
                verbal_transition_alert_instruction = '', 
                verbal_pre_transition_instruction = '', 
                verbal_post_transition_instruction = '', 
                street_names = [
                    'A1'
                    ], 
                begin_street_names = [
                    'A1'
                    ], 
                time = 1.337, 
                length = 1.337, 
                begin_shape_index = 56, 
                end_shape_index = 56, 
                toll = True, 
                rough = True, 
                gate = True, 
                ferry = True, 
                sign = stadiamaps.models.maneuver_sign.maneuverSign(
                    exit_number_elements = [
                        stadiamaps.models.maneuver_sign_element.maneuverSignElement(
                            text = '', 
                            is_route_number = True, 
                            consecutive_count = 56, )
                        ], 
                    exit_branch_elements = [
                        stadiamaps.models.maneuver_sign_element.maneuverSignElement(
                            text = '', 
                            is_route_number = True, 
                            consecutive_count = 56, )
                        ], 
                    exit_toward_elements = [
                        
                        ], 
                    exit_name_elements = [
                        
                        ], ), 
                roundabout_exit_count = 56, 
                depart_instruction = 56, 
                verbal_depart_instruction = 56, 
                arrive_instruction = 56, 
                verbal_arrive_instruction = 56, 
                transit_info = { }, 
                verbal_multi_cue = True, 
                travel_mode = 'drive', 
                travel_type = 'car', 
                bss_maneuver_type = 'NoneAction'
            )
        else :
            return RouteManeuver(
                type = 56,
                instruction = '',
                time = 1.337,
                length = 1.337,
                begin_shape_index = 56,
                end_shape_index = 56,
                travel_mode = 'drive',
                travel_type = 'car',
        )
        """

    def testRouteManeuver(self):
        """Test RouteManeuver"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.1
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import stadiamaps
from stadiamaps.models.truck_costing_options import TruckCostingOptions  # noqa: E501
from stadiamaps.rest import ApiException

class TestTruckCostingOptions(unittest.TestCase):
    """TruckCostingOptions unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TruckCostingOptions
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TruckCostingOptions`
        """
        model = stadiamaps.models.truck_costing_options.TruckCostingOptions()  # noqa: E501
        if include_optional :
            return TruckCostingOptions(
                maneuver_penalty = 56, 
                gate_cost = 56, 
                gate_penalty = 56, 
                country_crossing_cost = 56, 
                country_crossing_penalty = 56, 
                service_penalty = 56, 
                service_factor = 1.337, 
                use_living_streets = 0, 
                use_ferry = 0, 
                height = 1.337, 
                width = 1.337, 
                toll_booth_cost = 56, 
                toll_booth_penalty = 56, 
                ferry_cost = 56, 
                use_highways = 0, 
                use_tolls = 0, 
                use_tracks = 0, 
                top_speed = 10, 
                shortest = True, 
                ignore_closures = True, 
                include_hov2 = True, 
                include_hov3 = True, 
                include_hot = True, 
                length = 1.337, 
                weight = 1.337, 
                axle_load = 1.337, 
                hazmat = True
            )
        else :
            return TruckCostingOptions(
        )
        """

    def testTruckCostingOptions(self):
        """Test TruckCostingOptions"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.4
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class TraceAttributeKey(str, Enum):
    """
    TraceAttributeKey
    """

    """
    allowed enum values
    """
    EDGE_DOT_NAMES = 'edge.names'
    EDGE_DOT_LENGTH = 'edge.length'
    EDGE_DOT_SPEED = 'edge.speed'
    EDGE_DOT_ROAD_CLASS = 'edge.road_class'
    EDGE_DOT_BEGIN_HEADING = 'edge.begin_heading'
    EDGE_DOT_END_HEADING = 'edge.end_heading'
    EDGE_DOT_BEGIN_SHAPE_INDEX = 'edge.begin_shape_index'
    EDGE_DOT_END_SHAPE_INDEX = 'edge.end_shape_index'
    EDGE_DOT_TRAVERSABILITY = 'edge.traversability'
    EDGE_DOT_USE = 'edge.use'
    EDGE_DOT_TOLL = 'edge.toll'
    EDGE_DOT_UNPAVED = 'edge.unpaved'
    EDGE_DOT_TUNNEL = 'edge.tunnel'
    EDGE_DOT_BRIDGE = 'edge.bridge'
    EDGE_DOT_ROUNDABOUT = 'edge.roundabout'
    EDGE_DOT_INTERNAL_INTERSECTION = 'edge.internal_intersection'
    EDGE_DOT_DRIVE_ON_RIGHT = 'edge.drive_on_right'
    EDGE_DOT_SURFACE = 'edge.surface'
    EDGE_DOT_SIGN_DOT_EXIT_NUMBER = 'edge.sign.exit_number'
    EDGE_DOT_SIGN_DOT_EXIT_BRANCH = 'edge.sign.exit_branch'
    EDGE_DOT_SIGN_DOT_EXIT_TOWARD = 'edge.sign.exit_toward'
    EDGE_DOT_SIGN_DOT_EXIT_NAME = 'edge.sign.exit_name'
    EDGE_DOT_TRAVEL_MODE = 'edge.travel_mode'
    EDGE_DOT_VEHICLE_TYPE = 'edge.vehicle_type'
    EDGE_DOT_PEDESTRIAN_TYPE = 'edge.pedestrian_type'
    EDGE_DOT_BICYCLE_TYPE = 'edge.bicycle_type'
    EDGE_DOT_TRANSIT_TYPE = 'edge.transit_type'
    EDGE_DOT_ID = 'edge.id'
    EDGE_DOT_WAY_ID = 'edge.way_id'
    EDGE_DOT_WEIGHTED_GRADE = 'edge.weighted_grade'
    EDGE_DOT_MAX_UPWARD_GRADE = 'edge.max_upward_grade'
    EDGE_DOT_MAX_DOWNWARD_GRADE = 'edge.max_downward_grade'
    EDGE_DOT_MEAN_ELEVATION = 'edge.mean_elevation'
    EDGE_DOT_LANE_COUNT = 'edge.lane_count'
    EDGE_DOT_CYCLE_LANE = 'edge.cycle_lane'
    EDGE_DOT_BICYCLE_NETWORK = 'edge.bicycle_network'
    EDGE_DOT_SAC_SCALE = 'edge.sac_scale'
    EDGE_DOT_SIDEWALK = 'edge.sidewalk'
    EDGE_DOT_DENSITY = 'edge.density'
    EDGE_DOT_SPEED_LIMIT = 'edge.speed_limit'
    EDGE_DOT_TRUCK_SPEED = 'edge.truck_speed'
    EDGE_DOT_TRUCK_ROUTE = 'edge.truck_route'
    NODE_DOT_INTERSECTING_EDGE_DOT_BEGIN_HEADING = 'node.intersecting_edge.begin_heading'
    NODE_DOT_INTERSECTING_EDGE_DOT_FROM_EDGE_NAME_CONSISTENCY = 'node.intersecting_edge.from_edge_name_consistency'
    NODE_DOT_INTERSECTING_EDGE_DOT_TO_EDGE_NAME_CONSISTENCY = 'node.intersecting_edge.to_edge_name_consistency'
    NODE_DOT_INTERSECTING_EDGE_DOT_DRIVEABILITY = 'node.intersecting_edge.driveability'
    NODE_DOT_INTERSECTING_EDGE_DOT_CYCLABILITY = 'node.intersecting_edge.cyclability'
    NODE_DOT_INTERSECTING_EDGE_DOT_WALKABILITY = 'node.intersecting_edge.walkability'
    NODE_DOT_INTERSECTING_EDGE_DOT_USE = 'node.intersecting_edge.use'
    NODE_DOT_INTERSECTING_EDGE_DOT_ROAD_CLASS = 'node.intersecting_edge.road_class'
    NODE_DOT_ELAPSED_TIME = 'node.elapsed_time'
    NODE_DOT_ADMIN_INDEX = 'node.admin_index'
    NODE_DOT_TYPE = 'node.type'
    NODE_DOT_FORK = 'node.fork'
    NODE_DOT_TIME_ZONE = 'node.time_zone'
    OSM_CHANGESET = 'osm_changeset'
    SHAPE = 'shape'
    ADMIN_DOT_COUNTRY_CODE = 'admin.country_code'
    ADMIN_DOT_COUNTRY_TEXT = 'admin.country_text'
    ADMIN_DOT_STATE_CODE = 'admin.state_code'
    ADMIN_DOT_STATE_TEXT = 'admin.state_text'
    MATCHED_DOT_POINT = 'matched.point'
    MATCHED_DOT_TYPE = 'matched.type'
    MATCHED_DOT_EDGE_INDEX = 'matched.edge_index'
    MATCHED_DOT_BEGIN_ROUTE_DISCONTINUITY = 'matched.begin_route_discontinuity'
    MATCHED_DOT_END_ROUTE_DISCONTINUITY = 'matched.end_route_discontinuity'
    MATCHED_DOT_DISTANCE_ALONG_EDGE = 'matched.distance_along_edge'
    MATCHED_DOT_DISTANCE_FROM_TRACE_POINT = 'matched.distance_from_trace_point'

    @classmethod
    def from_json(cls, json_str: str) -> TraceAttributeKey:
        """Create an instance of TraceAttributeKey from a JSON string"""
        return TraceAttributeKey(json.loads(json_str))





# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.4
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictInt, StrictStr

class TzResponse(BaseModel):
    """
    TzResponse
    """
    tz_id: StrictStr = Field(..., description="The canonical time zone ID. In the event that multiple time zones could be returned, the first one from the Unicode CLDR timezone.xml is returned.")
    base_utc_offset: StrictInt = Field(..., description="The base offset, in seconds, from UTC that is normally in effect for this time zone.")
    dst_offset: StrictInt = Field(..., description="The special offset, in seconds, from UTC that is in effect for this time zone as of the queried timestamp (defaults to now). If no additional offsets are in effect, this value is zero. This typically reflects Daylight Saving Time, but may indicate other special offsets. To get the total offset in effect, add `dst_offset` and `utc_offset` together.")
    additional_properties: Dict[str, Any] = {}
    __properties = ["tz_id", "base_utc_offset", "dst_offset"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TzResponse:
        """Create an instance of TzResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "additional_properties"
                          },
                          exclude_none=True)
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TzResponse:
        """Create an instance of TzResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return TzResponse.parse_obj(obj)

        _obj = TzResponse.parse_obj({
            "tz_id": obj.get("tz_id"),
            "base_utc_offset": obj.get("base_utc_offset"),
            "dst_offset": obj.get("dst_offset")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj




# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.4
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, StrictStr, conlist, validator
from stadiamaps.models.trace_attribute_key import TraceAttributeKey

class TraceAttributeFilterOptions(BaseModel):
    """
    TraceAttributeFilterOptions
    """
    attributes: conlist(TraceAttributeKey, min_items=1) = Field(...)
    action: StrictStr = Field(..., description="Determines whether the list of attributes will be used as a whitelist or a blacklist.")
    additional_properties: Dict[str, Any] = {}
    __properties = ["attributes", "action"]

    @validator('action')
    def action_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('include', 'exclude'):
            raise ValueError("must be one of enum values ('include', 'exclude')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TraceAttributeFilterOptions:
        """Create an instance of TraceAttributeFilterOptions from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "additional_properties"
                          },
                          exclude_none=True)
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TraceAttributeFilterOptions:
        """Create an instance of TraceAttributeFilterOptions from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return TraceAttributeFilterOptions.parse_obj(obj)

        _obj = TraceAttributeFilterOptions.parse_obj({
            "attributes": obj.get("attributes"),
            "action": obj.get("action")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj




# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.4
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, conint, conlist, validator
from stadiamaps.models.coordinate import Coordinate

class HeightRequest(BaseModel):
    """
    HeightRequest
    """
    id: Optional[StrictStr] = Field(None, description="An identifier to disambiguate requests (echoed by the server).")
    shape: Optional[conlist(Coordinate)] = Field(None, description="REQUIRED if `encoded_polyline` is not present.")
    encoded_polyline: Optional[StrictStr] = Field(None, description="REQUIRED if `shape` is not present. An encoded polyline (https://developers.google.com/maps/documentation/utilities/polylinealgorithm).")
    shape_format: Optional[StrictStr] = Field('polyline6', description="Specifies whether the polyline is encoded with 6 digit precision (polyline6) or 5 digit precision (polyline5).")
    range: Optional[StrictBool] = Field(False, description="Controls whether or not the returned array is one-dimensional (height only) or two-dimensional (with a range and height). The range dimension can be used to generate a graph or steepness gradient along a route.")
    height_precision: Optional[conint(strict=True, le=2, ge=0)] = Field(0, description="The decimal precision (number of digits after the point) of the output. When 0, integer values are returned. Valid values are 0, 1, and 2.")
    additional_properties: Dict[str, Any] = {}
    __properties = ["id", "shape", "encoded_polyline", "shape_format", "range", "height_precision"]

    @validator('shape_format')
    def shape_format_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('polyline6', 'polyline5'):
            raise ValueError("must be one of enum values ('polyline6', 'polyline5')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> HeightRequest:
        """Create an instance of HeightRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "additional_properties"
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in shape (list)
        _items = []
        if self.shape:
            for _item in self.shape:
                if _item:
                    _items.append(_item.to_dict())
            _dict['shape'] = _items
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> HeightRequest:
        """Create an instance of HeightRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return HeightRequest.parse_obj(obj)

        _obj = HeightRequest.parse_obj({
            "id": obj.get("id"),
            "shape": [Coordinate.from_dict(_item) for _item in obj.get("shape")] if obj.get("shape") is not None else None,
            "encoded_polyline": obj.get("encoded_polyline"),
            "shape_format": obj.get("shape_format") if obj.get("shape_format") is not None else 'polyline6',
            "range": obj.get("range") if obj.get("range") is not None else False,
            "height_precision": obj.get("height_precision") if obj.get("height_precision") is not None else 0
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj




# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.4
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class EdgeUse(str, Enum):
    """
    The use for the edge.
    """

    """
    allowed enum values
    """
    ROAD = 'road'
    RAMP = 'ramp'
    TURN_CHANNEL = 'turn_channel'
    TRACK = 'track'
    DRIVEWAY = 'driveway'
    ALLEY = 'alley'
    PARKING_AISLE = 'parking_aisle'
    EMERGENCY_ACCESS = 'emergency_access'
    DRIVE_THROUGH = 'drive_through'
    CULDESAC = 'culdesac'
    LIVING_STREET = 'living_street'
    SERVICE_ROAD = 'service_road'
    CYCLEWAY = 'cycleway'
    MOUNTAIN_BIKE = 'mountain_bike'
    SIDEWALK = 'sidewalk'
    FOOTWAY = 'footway'
    STEPS = 'steps'
    PATH = 'path'
    PEDESTRIAN = 'pedestrian'
    PEDESTRIAN_CROSSING = 'pedestrian_crossing'
    BRIDLEWAY = 'bridleway'
    REST_AREA = 'rest_area'
    SERVICE_AREA = 'service_area'
    OTHER = 'other'
    FERRY = 'ferry'
    RAIL_MINUS_FERRY = 'rail-ferry'
    RAIL = 'rail'
    BUS = 'bus'
    EGRESS_CONNECTION = 'egress_connection'
    PLATFORM_CONNECTION = 'platform_connection'
    TRANSIT_CONNECTION = 'transit_connection'

    @classmethod
    def from_json(cls, json_str: str) -> EdgeUse:
        """Create an instance of EdgeUse from a JSON string"""
        return EdgeUse(json.loads(json_str))





# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.1
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import stadiamaps
from stadiamaps.models.travel_mode import TravelMode  # noqa: E501
from stadiamaps.rest import ApiException

class TestTravelMode(unittest.TestCase):
    """TravelMode unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTravelMode(self):
        """Test TravelMode"""
        # inst = TravelMode()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.4
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, confloat, conint

class PedestrianCostingOptions(BaseModel):
    """
    PedestrianCostingOptions
    """
    walking_speed: Optional[conint(strict=True, le=25, ge=0)] = Field(None, description="Walking speed in kph.")
    walkway_factor: Optional[Union[StrictFloat, StrictInt]] = Field(1, description="A factor that multiplies the cost when walkways are encountered.")
    sidewalk_factor: Optional[Union[StrictFloat, StrictInt]] = Field(1, description="A factor that multiplies the cost when sidewalks are encountered.")
    alley_factor: Optional[Union[StrictFloat, StrictInt]] = Field(2, description="A factor that multiplies the cost when alleys are encountered.")
    driveway_factor: Optional[Union[StrictFloat, StrictInt]] = Field(5, description="A factor that multiplies the cost when driveways are encountered.")
    step_penalty: Optional[StrictInt] = Field(30, description="A penalty (in seconds) added to each transition onto a path with steps or stairs.")
    use_ferry: Optional[Union[confloat(le=1, ge=0, strict=True), conint(le=1, ge=0, strict=True)]] = Field(0.5, description="A measure of willingness to take ferries. Values near 0 attempt to avoid ferries, and values near 1 will favour them. Note that as some routes may be impossible without ferries, 0 does not guarantee avoidance of them.")
    use_living_streets: Optional[Union[confloat(le=1, ge=0, strict=True), conint(le=1, ge=0, strict=True)]] = Field(None, description="A measure of willingness to take living streets. Values near 0 attempt to avoid them, and values near 1 will favour them. Note that as some routes may be impossible without living streets, 0 does not guarantee avoidance of them. The default value is 0 for trucks; 0.1 for other motor vehicles; 0.5 for bicycles; and 0.6 for pedestrians.")
    use_tracks: Optional[Union[confloat(le=1, ge=0, strict=True), conint(le=1, ge=0, strict=True)]] = Field(None, description="A measure of willingness to take track roads. Values near 0 attempt to avoid them, and values near 1 will favour them. Note that as some routes may be impossible without track roads, 0 does not guarantee avoidance of them. The default value is 0 for automobiles, busses, and trucks; and 0.5 for all other costing modes.")
    use_hills: Optional[Union[confloat(le=1, ge=0, strict=True), conint(le=1, ge=0, strict=True)]] = Field(0.5, description="A measure of willingness to take tackle hills. Values near 0 attempt to avoid hills and steeper grades even if it means a longer route, and values near 1 indicates that the user does not fear them. Note that as some routes may be impossible without hills, 0 does not guarantee avoidance of them.")
    use_lit: Optional[Union[confloat(le=1, ge=0, strict=True), conint(le=1, ge=0, strict=True)]] = Field(0, description="A measure of preference for streets that are lit. 0 indicates indifference toward lit streets, and 1 indicates that unlit streets should be avoided. Note that even with values near 1, there is no guarantee that the returned route will include lit segments.")
    service_penalty: Optional[StrictInt] = Field(None, description="A penalty applied to transitions to service roads. This penalty can be used to reduce the likelihood of suggesting a route with service roads unless absolutely necessary. The default penalty is 15 for cars, busses, motor scooters, and motorcycles; and zero for others.")
    service_factor: Optional[Union[StrictFloat, StrictInt]] = Field(1, description="A factor that multiplies the cost when service roads are encountered. The default is 1.2 for cars and busses, and 1 for trucks, motor scooters, and motorcycles.")
    max_hiking_difficulty: Optional[conint(strict=True, le=6, ge=1)] = Field(1, description="The maximum difficulty of hiking trails allowed. This corresponds to the OSM `sac_scale`.")
    bss_rent_cost: Optional[StrictInt] = Field(120, description="The estimated cost (in seconds) to rent a bicycle from a sharing station in `bikeshare` mode.")
    bss_rent_penalty: Optional[StrictInt] = Field(0, description="A penalty (in seconds) to rent a bicycle in `bikeshare` mode.")
    additional_properties: Dict[str, Any] = {}
    __properties = ["walking_speed", "walkway_factor", "sidewalk_factor", "alley_factor", "driveway_factor", "step_penalty", "use_ferry", "use_living_streets", "use_tracks", "use_hills", "use_lit", "service_penalty", "service_factor", "max_hiking_difficulty", "bss_rent_cost", "bss_rent_penalty"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PedestrianCostingOptions:
        """Create an instance of PedestrianCostingOptions from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "additional_properties"
                          },
                          exclude_none=True)
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PedestrianCostingOptions:
        """Create an instance of PedestrianCostingOptions from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PedestrianCostingOptions.parse_obj(obj)

        _obj = PedestrianCostingOptions.parse_obj({
            "walking_speed": obj.get("walking_speed"),
            "walkway_factor": obj.get("walkway_factor") if obj.get("walkway_factor") is not None else 1,
            "sidewalk_factor": obj.get("sidewalk_factor") if obj.get("sidewalk_factor") is not None else 1,
            "alley_factor": obj.get("alley_factor") if obj.get("alley_factor") is not None else 2,
            "driveway_factor": obj.get("driveway_factor") if obj.get("driveway_factor") is not None else 5,
            "step_penalty": obj.get("step_penalty") if obj.get("step_penalty") is not None else 30,
            "use_ferry": obj.get("use_ferry") if obj.get("use_ferry") is not None else 0.5,
            "use_living_streets": obj.get("use_living_streets"),
            "use_tracks": obj.get("use_tracks"),
            "use_hills": obj.get("use_hills") if obj.get("use_hills") is not None else 0.5,
            "use_lit": obj.get("use_lit") if obj.get("use_lit") is not None else 0,
            "service_penalty": obj.get("service_penalty"),
            "service_factor": obj.get("service_factor") if obj.get("service_factor") is not None else 1,
            "max_hiking_difficulty": obj.get("max_hiking_difficulty") if obj.get("max_hiking_difficulty") is not None else 1,
            "bss_rent_cost": obj.get("bss_rent_cost") if obj.get("bss_rent_cost") is not None else 120,
            "bss_rent_penalty": obj.get("bss_rent_penalty") if obj.get("bss_rent_penalty") is not None else 0
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj




# coding: utf-8

# flake8: noqa

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.4
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


__version__ = "1.0.5"

# import apis into sdk package
from stadiamaps.api.geocoding_api import GeocodingApi
from stadiamaps.api.geospatial_api import GeospatialApi
from stadiamaps.api.routing_api import RoutingApi

# import ApiClient
from stadiamaps.api_response import ApiResponse
from stadiamaps.api_client import ApiClient
from stadiamaps.configuration import Configuration
from stadiamaps.exceptions import OpenApiException
from stadiamaps.exceptions import ApiTypeError
from stadiamaps.exceptions import ApiValueError
from stadiamaps.exceptions import ApiKeyError
from stadiamaps.exceptions import ApiAttributeError
from stadiamaps.exceptions import ApiException

# import models into sdk package
from stadiamaps.models.access import Access
from stadiamaps.models.admin_region import AdminRegion
from stadiamaps.models.administrative import Administrative
from stadiamaps.models.auto_costing_options import AutoCostingOptions
from stadiamaps.models.auto_costing_options_all_of import AutoCostingOptionsAllOf
from stadiamaps.models.base_costing_options import BaseCostingOptions
from stadiamaps.models.base_trace_request import BaseTraceRequest
from stadiamaps.models.bicycle_costing_options import BicycleCostingOptions
from stadiamaps.models.bicycle_costing_options_all_of import BicycleCostingOptionsAllOf
from stadiamaps.models.bike_network import BikeNetwork
from stadiamaps.models.contour import Contour
from stadiamaps.models.coordinate import Coordinate
from stadiamaps.models.costing_model import CostingModel
from stadiamaps.models.costing_options import CostingOptions
from stadiamaps.models.directions_options import DirectionsOptions
from stadiamaps.models.distance_unit import DistanceUnit
from stadiamaps.models.edge_sign import EdgeSign
from stadiamaps.models.edge_use import EdgeUse
from stadiamaps.models.end_node import EndNode
from stadiamaps.models.geo_attributes import GeoAttributes
from stadiamaps.models.geo_json_geometry import GeoJSONGeometry
from stadiamaps.models.geo_json_geometry_base import GeoJSONGeometryBase
from stadiamaps.models.geo_json_line_string import GeoJSONLineString
from stadiamaps.models.geo_json_line_string_all_of import GeoJSONLineStringAllOf
from stadiamaps.models.geo_json_point import GeoJSONPoint
from stadiamaps.models.geo_json_point_all_of import GeoJSONPointAllOf
from stadiamaps.models.geo_json_polygon import GeoJSONPolygon
from stadiamaps.models.geo_json_polygon_all_of import GeoJSONPolygonAllOf
from stadiamaps.models.geocoding_object import GeocodingObject
from stadiamaps.models.height_request import HeightRequest
from stadiamaps.models.height_response import HeightResponse
from stadiamaps.models.highway_classification import HighwayClassification
from stadiamaps.models.intersecting_edge import IntersectingEdge
from stadiamaps.models.isochrone_costing_model import IsochroneCostingModel
from stadiamaps.models.isochrone_feature import IsochroneFeature
from stadiamaps.models.isochrone_properties import IsochroneProperties
from stadiamaps.models.isochrone_request import IsochroneRequest
from stadiamaps.models.isochrone_response import IsochroneResponse
from stadiamaps.models.locate_detailed_edge import LocateDetailedEdge
from stadiamaps.models.locate_edge import LocateEdge
from stadiamaps.models.locate_edge_info import LocateEdgeInfo
from stadiamaps.models.locate_node import LocateNode
from stadiamaps.models.locate_node_all_of import LocateNodeAllOf
from stadiamaps.models.locate_object import LocateObject
from stadiamaps.models.maneuver_sign import ManeuverSign
from stadiamaps.models.maneuver_sign_element import ManeuverSignElement
from stadiamaps.models.map_match_costing_model import MapMatchCostingModel
from stadiamaps.models.map_match_request import MapMatchRequest
from stadiamaps.models.map_match_request_all_of import MapMatchRequestAllOf
from stadiamaps.models.map_match_route_response import MapMatchRouteResponse
from stadiamaps.models.map_match_route_response_all_of import MapMatchRouteResponseAllOf
from stadiamaps.models.map_match_trace_options import MapMatchTraceOptions
from stadiamaps.models.map_match_waypoint import MapMatchWaypoint
from stadiamaps.models.map_match_waypoint_all_of import MapMatchWaypointAllOf
from stadiamaps.models.matched_point import MatchedPoint
from stadiamaps.models.matrix_costing_model import MatrixCostingModel
from stadiamaps.models.matrix_distance import MatrixDistance
from stadiamaps.models.matrix_request import MatrixRequest
from stadiamaps.models.matrix_response import MatrixResponse
from stadiamaps.models.motor_scooter_costing_options import MotorScooterCostingOptions
from stadiamaps.models.motor_scooter_costing_options_all_of import MotorScooterCostingOptionsAllOf
from stadiamaps.models.motorcycle_costing_options import MotorcycleCostingOptions
from stadiamaps.models.motorcycle_costing_options_all_of import MotorcycleCostingOptionsAllOf
from stadiamaps.models.nearest_roads_request import NearestRoadsRequest
from stadiamaps.models.node_id import NodeId
from stadiamaps.models.node_type import NodeType
from stadiamaps.models.optimized_route_request import OptimizedRouteRequest
from stadiamaps.models.pedestrian_costing_options import PedestrianCostingOptions
from stadiamaps.models.pelias_geo_json_feature import PeliasGeoJSONFeature
from stadiamaps.models.pelias_geo_json_properties import PeliasGeoJSONProperties
from stadiamaps.models.pelias_geo_json_properties_addendum import PeliasGeoJSONPropertiesAddendum
from stadiamaps.models.pelias_geo_json_properties_addendum_osm import PeliasGeoJSONPropertiesAddendumOsm
from stadiamaps.models.pelias_layer import PeliasLayer
from stadiamaps.models.pelias_response import PeliasResponse
from stadiamaps.models.pelias_response_geocoding import PeliasResponseGeocoding
from stadiamaps.models.pelias_source import PeliasSource
from stadiamaps.models.restrictions import Restrictions
from stadiamaps.models.road_class import RoadClass
from stadiamaps.models.route_leg import RouteLeg
from stadiamaps.models.route_maneuver import RouteManeuver
from stadiamaps.models.route_request import RouteRequest
from stadiamaps.models.route_response import RouteResponse
from stadiamaps.models.route_response_trip import RouteResponseTrip
from stadiamaps.models.route_summary import RouteSummary
from stadiamaps.models.routing_response_waypoint import RoutingResponseWaypoint
from stadiamaps.models.routing_response_waypoint_all_of import RoutingResponseWaypointAllOf
from stadiamaps.models.routing_waypoint import RoutingWaypoint
from stadiamaps.models.routing_waypoint_all_of import RoutingWaypointAllOf
from stadiamaps.models.routing_waypoint_all_of_search_filter import RoutingWaypointAllOfSearchFilter
from stadiamaps.models.simple_routing_waypoint import SimpleRoutingWaypoint
from stadiamaps.models.simple_routing_waypoint_all_of import SimpleRoutingWaypointAllOf
from stadiamaps.models.speeds import Speeds
from stadiamaps.models.trace_attribute_filter_options import TraceAttributeFilterOptions
from stadiamaps.models.trace_attribute_key import TraceAttributeKey
from stadiamaps.models.trace_attributes_base_response import TraceAttributesBaseResponse
from stadiamaps.models.trace_attributes_request import TraceAttributesRequest
from stadiamaps.models.trace_attributes_request_all_of import TraceAttributesRequestAllOf
from stadiamaps.models.trace_attributes_request_all_of_filters import TraceAttributesRequestAllOfFilters
from stadiamaps.models.trace_attributes_response import TraceAttributesResponse
from stadiamaps.models.trace_attributes_response_all_of import TraceAttributesResponseAllOf
from stadiamaps.models.trace_edge import TraceEdge
from stadiamaps.models.travel_mode import TravelMode
from stadiamaps.models.traversability import Traversability
from stadiamaps.models.truck_costing_options import TruckCostingOptions
from stadiamaps.models.truck_costing_options_all_of import TruckCostingOptionsAllOf
from stadiamaps.models.tz_response import TzResponse
from stadiamaps.models.valhalla_languages import ValhallaLanguages
from stadiamaps.models.valhalla_long_units import ValhallaLongUnits
from stadiamaps.models.warning import Warning



# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.1
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import stadiamaps
from stadiamaps.models.pelias_geo_json_properties import PeliasGeoJSONProperties  # noqa: E501
from stadiamaps.rest import ApiException

class TestPeliasGeoJSONProperties(unittest.TestCase):
    """PeliasGeoJSONProperties unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PeliasGeoJSONProperties
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PeliasGeoJSONProperties`
        """
        model = stadiamaps.models.pelias_geo_json_properties.PeliasGeoJSONProperties()  # noqa: E501
        if include_optional :
            return PeliasGeoJSONProperties(
                gid = '', 
                source_id = '', 
                label = '', 
                layer = 'venue', 
                name = '', 
                accuracy = 'point', 
                addendum = { }, 
                continent = '', 
                continent_gid = '', 
                country = '', 
                country_gid = '', 
                neighbourhood = '', 
                neighbourhood_gid = '', 
                borough = '', 
                borough_gid = '', 
                postalcode = '', 
                street = '', 
                housenumber = '', 
                locality = '', 
                lecality_gid = '', 
                county = '', 
                region = '', 
                region_a = ''
            )
        else :
            return PeliasGeoJSONProperties(
        )
        """

    def testPeliasGeoJSONProperties(self):
        """Test PeliasGeoJSONProperties"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.4
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr, conlist, validator
from stadiamaps.models.locate_detailed_edge import LocateDetailedEdge
from stadiamaps.models.locate_edge_info import LocateEdgeInfo
from stadiamaps.models.node_id import NodeId

class LocateEdge(BaseModel):
    """
    LocateEdge
    """
    edge_id: Optional[NodeId] = None
    correlated_lat: Optional[Union[StrictFloat, StrictInt]] = None
    correlated_lon: Optional[Union[StrictFloat, StrictInt]] = None
    percent_along: Optional[Union[StrictFloat, StrictInt]] = None
    side_of_street: Optional[StrictStr] = None
    linear_reference: Optional[StrictStr] = Field(None, description="A base64-encoded [OpenLR location reference](https://www.openlr-association.com/fileadmin/user_upload/openlr-whitepaper_v1.5.pdf), for a graph edge of the road network matched by the query.")
    outbound_reach: Optional[StrictInt] = None
    heading: Optional[Union[StrictFloat, StrictInt]] = None
    inbound_reach: Optional[StrictInt] = None
    distance: Optional[Union[StrictFloat, StrictInt]] = None
    predicted_speeds: Optional[conlist(StrictInt)] = Field(None, description="Predicted speed information based on historical data. If available, this will include 2016 entries. Each entry represents 5 minutes, where the first entry represents midnight on Monday, the second entry represents 00:05 on Monday, etc.")
    edge_info: Optional[LocateEdgeInfo] = None
    edge: Optional[LocateDetailedEdge] = None
    warnings: Optional[conlist(StrictStr)] = None
    additional_properties: Dict[str, Any] = {}
    __properties = ["edge_id", "correlated_lat", "correlated_lon", "percent_along", "side_of_street", "linear_reference", "outbound_reach", "heading", "inbound_reach", "distance", "predicted_speeds", "edge_info", "edge", "warnings"]

    @validator('side_of_street')
    def side_of_street_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('left', 'right', 'neither'):
            raise ValueError("must be one of enum values ('left', 'right', 'neither')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> LocateEdge:
        """Create an instance of LocateEdge from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "additional_properties"
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of edge_id
        if self.edge_id:
            _dict['edge_id'] = self.edge_id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of edge_info
        if self.edge_info:
            _dict['edge_info'] = self.edge_info.to_dict()
        # override the default output from pydantic by calling `to_dict()` of edge
        if self.edge:
            _dict['edge'] = self.edge.to_dict()
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> LocateEdge:
        """Create an instance of LocateEdge from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return LocateEdge.parse_obj(obj)

        _obj = LocateEdge.parse_obj({
            "edge_id": NodeId.from_dict(obj.get("edge_id")) if obj.get("edge_id") is not None else None,
            "correlated_lat": obj.get("correlated_lat"),
            "correlated_lon": obj.get("correlated_lon"),
            "percent_along": obj.get("percent_along"),
            "side_of_street": obj.get("side_of_street"),
            "linear_reference": obj.get("linear_reference"),
            "outbound_reach": obj.get("outbound_reach"),
            "heading": obj.get("heading"),
            "inbound_reach": obj.get("inbound_reach"),
            "distance": obj.get("distance"),
            "predicted_speeds": obj.get("predicted_speeds"),
            "edge_info": LocateEdgeInfo.from_dict(obj.get("edge_info")) if obj.get("edge_info") is not None else None,
            "edge": LocateDetailedEdge.from_dict(obj.get("edge")) if obj.get("edge") is not None else None,
            "warnings": obj.get("warnings")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj




# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.1
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import stadiamaps
from stadiamaps.models.routing_waypoint_all_of import RoutingWaypointAllOf  # noqa: E501
from stadiamaps.rest import ApiException

class TestRoutingWaypointAllOf(unittest.TestCase):
    """RoutingWaypointAllOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test RoutingWaypointAllOf
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RoutingWaypointAllOf`
        """
        model = stadiamaps.models.routing_waypoint_all_of.RoutingWaypointAllOf()  # noqa: E501
        if include_optional :
            return RoutingWaypointAllOf(
                heading = 0, 
                heading_tolerance = 0, 
                minimum_reachability = 0, 
                radius = 0, 
                rank_candidates = True, 
                preferred_side = 'same', 
                node_snap_tolerance = 0, 
                street_side_tolerance = 0, 
                street_side_max_distance = 0, 
                search_filter = stadiamaps.models.routing_waypoint_all_of_search_filter.routingWaypoint_allOf_search_filter(
                    exclude_tunnel = True, 
                    exclude_bridge = True, 
                    exclude_ramp = True, 
                    exclude_closures = True, 
                    min_road_class = null, 
                    max_road_class = null, )
            )
        else :
            return RoutingWaypointAllOf(
        )
        """

    def testRoutingWaypointAllOf(self):
        """Test RoutingWaypointAllOf"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.4
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, confloat, conint

class MotorScooterCostingOptionsAllOf(BaseModel):
    """
    MotorScooterCostingOptionsAllOf
    """
    use_primary: Optional[Union[confloat(le=1, ge=0, strict=True), conint(le=1, ge=0, strict=True)]] = Field(0.5, description="A measure of willingness to use primary roads. Values near 0 attempt to avoid primary roads and stay on roads with lower speeds, and values near 1 indicate the rider is more comfortable on these roads.")
    use_hills: Optional[Union[confloat(le=1, ge=0, strict=True), conint(le=1, ge=0, strict=True)]] = Field(0.5, description="A measure of willingness to take tackle hills. Values near 0 attempt to avoid hills and steeper grades even if it means a longer route, and values near 1 indicates that the rider does not fear them. Note that as some routes may be impossible without hills, 0 does not guarantee avoidance of them.")
    additional_properties: Dict[str, Any] = {}
    __properties = ["use_primary", "use_hills"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> MotorScooterCostingOptionsAllOf:
        """Create an instance of MotorScooterCostingOptionsAllOf from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "additional_properties"
                          },
                          exclude_none=True)
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> MotorScooterCostingOptionsAllOf:
        """Create an instance of MotorScooterCostingOptionsAllOf from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return MotorScooterCostingOptionsAllOf.parse_obj(obj)

        _obj = MotorScooterCostingOptionsAllOf.parse_obj({
            "use_primary": obj.get("use_primary") if obj.get("use_primary") is not None else 0.5,
            "use_hills": obj.get("use_hills") if obj.get("use_hills") is not None else 0.5
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj




# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.1
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import stadiamaps
from stadiamaps.api.geospatial_api import GeospatialApi  # noqa: E501
from stadiamaps.rest import ApiException


class TestGeospatialApi(unittest.TestCase):
    """GeospatialApi unit test stubs"""

    def setUp(self):
        self.api = stadiamaps.api.geospatial_api.GeospatialApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_elevation(self):
        """Test case for elevation

        Get the elevation profile along a polyline or at a point.  # noqa: E501
        """
        pass

    def test_tz_lookup(self):
        """Test case for tz_lookup

        Get the current time zone information for any point on earth.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.4
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class ValhallaLanguages(str, Enum):
    """
    ValhallaLanguages
    """

    """
    allowed enum values
    """
    BG_MINUS_BG = 'bg-BG'
    CA_MINUS_ES = 'ca-ES'
    CS_MINUS_CZ = 'cs-CZ'
    DA_MINUS_DK = 'da-DK'
    DE_MINUS_DE = 'de-DE'
    EL_MINUS_GR = 'el-GR'
    EN_MINUS_GB = 'en-GB'
    EN_MINUS_US_MINUS_X_MINUS_PIRATE = 'en-US-x-pirate'
    EN_MINUS_US = 'en-US'
    ES_MINUS_ES = 'es-ES'
    ET_MINUS_EE = 'et-EE'
    FI_MINUS_FI = 'fi-FI'
    FR_MINUS_FR = 'fr-FR'
    HI_MINUS_IN = 'hi-IN'
    HU_MINUS_HU = 'hu-HU'
    IT_MINUS_IT = 'it-IT'
    JA_MINUS_JP = 'ja-JP'
    NB_MINUS_NO = 'nb-NO'
    NL_MINUS_NL = 'nl-NL'
    PL_MINUS_PL = 'pl-PL'
    PT_MINUS_BR = 'pt-BR'
    PT_MINUS_PT = 'pt-PT'
    RO_MINUS_RO = 'ro-RO'
    RU_MINUS_RU = 'ru-RU'
    SK_MINUS_SK = 'sk-SK'
    SL_MINUS_SI = 'sl-SI'
    SV_MINUS_SE = 'sv-SE'
    TR_MINUS_TR = 'tr-TR'
    UK_MINUS_UA = 'uk-UA'

    @classmethod
    def from_json(cls, json_str: str) -> ValhallaLanguages:
        """Create an instance of ValhallaLanguages from a JSON string"""
        return ValhallaLanguages(json.loads(json_str))





# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.1
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import stadiamaps
from stadiamaps.models.route_response_trip import RouteResponseTrip  # noqa: E501
from stadiamaps.rest import ApiException

class TestRouteResponseTrip(unittest.TestCase):
    """RouteResponseTrip unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test RouteResponseTrip
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RouteResponseTrip`
        """
        model = stadiamaps.models.route_response_trip.RouteResponseTrip()  # noqa: E501
        if include_optional :
            return RouteResponseTrip(
                status = 56, 
                status_message = '', 
                units = 'kilometers', 
                language = 'en-US', 
                locations = [
                    null
                    ], 
                legs = [
                    stadiamaps.models.route_leg.routeLeg(
                        maneuvers = [
                            stadiamaps.models.route_maneuver.routeManeuver(
                                type = 56, 
                                instruction = '', 
                                verbal_transition_alert_instruction = '', 
                                verbal_pre_transition_instruction = '', 
                                verbal_post_transition_instruction = '', 
                                street_names = [
                                    'A1'
                                    ], 
                                begin_street_names = [
                                    'A1'
                                    ], 
                                time = 1.337, 
                                length = 1.337, 
                                begin_shape_index = 56, 
                                end_shape_index = 56, 
                                toll = True, 
                                rough = True, 
                                gate = True, 
                                ferry = True, 
                                sign = stadiamaps.models.maneuver_sign.maneuverSign(
                                    exit_number_elements = [
                                        stadiamaps.models.maneuver_sign_element.maneuverSignElement(
                                            text = '', 
                                            is_route_number = True, 
                                            consecutive_count = 56, )
                                        ], 
                                    exit_branch_elements = [
                                        stadiamaps.models.maneuver_sign_element.maneuverSignElement(
                                            text = '', 
                                            is_route_number = True, 
                                            consecutive_count = 56, )
                                        ], 
                                    exit_toward_elements = [
                                        
                                        ], 
                                    exit_name_elements = [
                                        
                                        ], ), 
                                roundabout_exit_count = 56, 
                                depart_instruction = 56, 
                                verbal_depart_instruction = 56, 
                                arrive_instruction = 56, 
                                verbal_arrive_instruction = 56, 
                                transit_info = { }, 
                                verbal_multi_cue = True, 
                                travel_mode = 'drive', 
                                travel_type = 'car', 
                                bss_maneuver_type = 'NoneAction', )
                            ], 
                        shape = '', 
                        summary = stadiamaps.models.route_summary.routeSummary(
                            time = 1.337, 
                            length = 1.337, 
                            min_lat = 1.337, 
                            max_lat = 1.337, 
                            min_lon = 1.337, 
                            max_lon = 1.337, ), )
                    ], 
                summary = stadiamaps.models.route_summary.routeSummary(
                    time = 1.337, 
                    length = 1.337, 
                    min_lat = 1.337, 
                    max_lat = 1.337, 
                    min_lon = 1.337, 
                    max_lon = 1.337, )
            )
        else :
            return RouteResponseTrip(
                status = 56,
                status_message = '',
                units = 'kilometers',
                language = 'en-US',
                locations = [
                    null
                    ],
                legs = [
                    stadiamaps.models.route_leg.routeLeg(
                        maneuvers = [
                            stadiamaps.models.route_maneuver.routeManeuver(
                                type = 56, 
                                instruction = '', 
                                verbal_transition_alert_instruction = '', 
                                verbal_pre_transition_instruction = '', 
                                verbal_post_transition_instruction = '', 
                                street_names = [
                                    'A1'
                                    ], 
                                begin_street_names = [
                                    'A1'
                                    ], 
                                time = 1.337, 
                                length = 1.337, 
                                begin_shape_index = 56, 
                                end_shape_index = 56, 
                                toll = True, 
                                rough = True, 
                                gate = True, 
                                ferry = True, 
                                sign = stadiamaps.models.maneuver_sign.maneuverSign(
                                    exit_number_elements = [
                                        stadiamaps.models.maneuver_sign_element.maneuverSignElement(
                                            text = '', 
                                            is_route_number = True, 
                                            consecutive_count = 56, )
                                        ], 
                                    exit_branch_elements = [
                                        stadiamaps.models.maneuver_sign_element.maneuverSignElement(
                                            text = '', 
                                            is_route_number = True, 
                                            consecutive_count = 56, )
                                        ], 
                                    exit_toward_elements = [
                                        
                                        ], 
                                    exit_name_elements = [
                                        
                                        ], ), 
                                roundabout_exit_count = 56, 
                                depart_instruction = 56, 
                                verbal_depart_instruction = 56, 
                                arrive_instruction = 56, 
                                verbal_arrive_instruction = 56, 
                                transit_info = { }, 
                                verbal_multi_cue = True, 
                                travel_mode = 'drive', 
                                travel_type = 'car', 
                                bss_maneuver_type = 'NoneAction', )
                            ], 
                        shape = '', 
                        summary = stadiamaps.models.route_summary.routeSummary(
                            time = 1.337, 
                            length = 1.337, 
                            min_lat = 1.337, 
                            max_lat = 1.337, 
                            min_lon = 1.337, 
                            max_lon = 1.337, ), )
                    ],
                summary = stadiamaps.models.route_summary.routeSummary(
                    time = 1.337, 
                    length = 1.337, 
                    min_lat = 1.337, 
                    max_lat = 1.337, 
                    min_lon = 1.337, 
                    max_lon = 1.337, ),
        )
        """

    def testRouteResponseTrip(self):
        """Test RouteResponseTrip"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.1
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import stadiamaps
from stadiamaps.models.geo_json_line_string_all_of import GeoJSONLineStringAllOf  # noqa: E501
from stadiamaps.rest import ApiException

class TestGeoJSONLineStringAllOf(unittest.TestCase):
    """GeoJSONLineStringAllOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test GeoJSONLineStringAllOf
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GeoJSONLineStringAllOf`
        """
        model = stadiamaps.models.geo_json_line_string_all_of.GeoJSONLineStringAllOf()  # noqa: E501
        if include_optional :
            return GeoJSONLineStringAllOf(
                coordinates = [
                    [
                        1.337
                        ]
                    ]
            )
        else :
            return GeoJSONLineStringAllOf(
                coordinates = [
                    [
                        1.337
                        ]
                    ],
        )
        """

    def testGeoJSONLineStringAllOf(self):
        """Test GeoJSONLineStringAllOf"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.1
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import stadiamaps
from stadiamaps.models.base_trace_request import BaseTraceRequest  # noqa: E501
from stadiamaps.rest import ApiException

class TestBaseTraceRequest(unittest.TestCase):
    """BaseTraceRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test BaseTraceRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BaseTraceRequest`
        """
        model = stadiamaps.models.base_trace_request.BaseTraceRequest()  # noqa: E501
        if include_optional :
            return BaseTraceRequest(
                id = 'kesklinn', 
                shape = [
                    null
                    ], 
                encoded_polyline = '', 
                costing = 'auto', 
                costing_options = stadiamaps.models.costing_options.costingOptions(
                    auto = null, 
                    bus = null, 
                    taxi = null, 
                    truck = null, 
                    bicycle = null, 
                    motor_scooter = null, 
                    motorcycle = null, 
                    pedestrian = stadiamaps.models.pedestrian_costing_options.pedestrianCostingOptions(
                        walking_speed = 0.5, 
                        walkway_factor = 1.337, 
                        sidewalk_factor = 1.337, 
                        alley_factor = 1.337, 
                        driveway_factor = 1.337, 
                        step_penalty = 56, 
                        use_ferry = 0, 
                        use_living_streets = 0, 
                        use_tracks = 0, 
                        use_hills = 0, 
                        use_lit = 0, 
                        service_penalty = 56, 
                        service_factor = 1.337, 
                        max_hiking_difficulty = 1, 
                        bss_rent_cost = 56, 
                        bss_rent_penalty = 56, ), ), 
                shape_match = 'edge_walk', 
                directions_options = stadiamaps.models.directions_options.directionsOptions(
                    units = 'km', 
                    language = 'en-US', 
                    directions_type = 'instructions', )
            )
        else :
            return BaseTraceRequest(
                costing = 'auto',
        )
        """

    def testBaseTraceRequest(self):
        """Test BaseTraceRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.4
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr, confloat, conint, validator

class BicycleCostingOptions(BaseModel):
    """
    BicycleCostingOptions
    """
    maneuver_penalty: Optional[StrictInt] = Field(5, description="A penalty (in seconds) applied when transitioning between roads (determined by name).")
    gate_cost: Optional[StrictInt] = Field(15, description="The estimated cost (in seconds) when a gate is encountered.")
    gate_penalty: Optional[StrictInt] = Field(300, description="A penalty (in seconds) applied to the route cost when a gate is encountered. This penalty can be used to reduce the likelihood of suggesting a route with gates unless absolutely necessary.")
    country_crossing_cost: Optional[StrictInt] = Field(600, description="The estimated cost (in seconds) when encountering an international border.")
    country_crossing_penalty: Optional[StrictInt] = Field(0, description="A penalty applied to transitions to international border crossings. This penalty can be used to reduce the likelihood of suggesting a route with border crossings unless absolutely necessary.")
    service_penalty: Optional[StrictInt] = Field(None, description="A penalty applied to transitions to service roads. This penalty can be used to reduce the likelihood of suggesting a route with service roads unless absolutely necessary. The default penalty is 15 for cars, busses, motor scooters, and motorcycles; and zero for others.")
    service_factor: Optional[Union[StrictFloat, StrictInt]] = Field(1, description="A factor that multiplies the cost when service roads are encountered. The default is 1.2 for cars and busses, and 1 for trucks, motor scooters, and motorcycles.")
    use_living_streets: Optional[Union[confloat(le=1, ge=0, strict=True), conint(le=1, ge=0, strict=True)]] = Field(None, description="A measure of willingness to take living streets. Values near 0 attempt to avoid them, and values near 1 will favour them. Note that as some routes may be impossible without living streets, 0 does not guarantee avoidance of them. The default value is 0 for trucks; 0.1 for other motor vehicles; 0.5 for bicycles; and 0.6 for pedestrians.")
    use_ferry: Optional[Union[confloat(le=1, ge=0, strict=True), conint(le=1, ge=0, strict=True)]] = Field(0.5, description="A measure of willingness to take ferries. Values near 0 attempt to avoid ferries, and values near 1 will favour them. Note that as some routes may be impossible without ferries, 0 does not guarantee avoidance of them.")
    bicycle_type: Optional[StrictStr] = 'Hybrid'
    cycling_speed: Optional[StrictInt] = Field(None, description="The average comfortable travel speed (in kph) along smooth, flat roads. The costing will vary the speed based on the surface, bicycle type, elevation change, etc. This value should be the average sustainable cruising speed the cyclist can maintain over the entire route. The default speeds are as follows based on bicycle type:   * Road - 25kph   * Cross - 20kph   * Hybrid - 18kph   * Mountain - 16kph")
    use_roads: Optional[Union[confloat(le=1, ge=0, strict=True), conint(le=1, ge=0, strict=True)]] = Field(0.5, description="A measure of willingness to use roads alongside other vehicles. Values near 0 attempt to avoid roads and stay on cycleways, and values near 1 indicate the cyclist is more comfortable on roads.")
    use_hills: Optional[Union[confloat(le=1, ge=0, strict=True), conint(le=1, ge=0, strict=True)]] = Field(0.5, description="A measure of willingness to take tackle hills. Values near 0 attempt to avoid hills and steeper grades even if it means a longer route, and values near 1 indicates that the user does not fear them. Note that as some routes may be impossible without hills, 0 does not guarantee avoidance of them.")
    avoid_bad_surfaces: Optional[Union[confloat(le=1, ge=0, strict=True), conint(le=1, ge=0, strict=True)]] = Field(0.25, description="A measure of how much the cyclist wants to avoid roads with poor surfaces relative to the type of bicycle being ridden. When 0, there is no penalization of roads with poorer surfaces, and only bicycle speed is taken into account. As the value approaches 1, roads with poor surfaces relative to the bicycle type receive a heaver penalty, so they will only be taken if they significantly reduce travel time. When the value is 1, all bad surfaces are completely avoided from the route, including the start and end points.")
    bss_return_cost: Optional[StrictInt] = Field(120, description="The estimated cost (in seconds) to return a bicycle in `bikeshare` mode.")
    bss_return_penalty: Optional[StrictInt] = Field(0, description="A penalty (in seconds) to return a bicycle in `bikeshare` mode.")
    additional_properties: Dict[str, Any] = {}
    __properties = ["maneuver_penalty", "gate_cost", "gate_penalty", "country_crossing_cost", "country_crossing_penalty", "service_penalty", "service_factor", "use_living_streets", "use_ferry", "bicycle_type", "cycling_speed", "use_roads", "use_hills", "avoid_bad_surfaces", "bss_return_cost", "bss_return_penalty"]

    @validator('bicycle_type')
    def bicycle_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('Road', 'Hybrid', 'Cross', 'Mountain'):
            raise ValueError("must be one of enum values ('Road', 'Hybrid', 'Cross', 'Mountain')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> BicycleCostingOptions:
        """Create an instance of BicycleCostingOptions from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "additional_properties"
                          },
                          exclude_none=True)
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> BicycleCostingOptions:
        """Create an instance of BicycleCostingOptions from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return BicycleCostingOptions.parse_obj(obj)

        _obj = BicycleCostingOptions.parse_obj({
            "maneuver_penalty": obj.get("maneuver_penalty") if obj.get("maneuver_penalty") is not None else 5,
            "gate_cost": obj.get("gate_cost") if obj.get("gate_cost") is not None else 15,
            "gate_penalty": obj.get("gate_penalty") if obj.get("gate_penalty") is not None else 300,
            "country_crossing_cost": obj.get("country_crossing_cost") if obj.get("country_crossing_cost") is not None else 600,
            "country_crossing_penalty": obj.get("country_crossing_penalty") if obj.get("country_crossing_penalty") is not None else 0,
            "service_penalty": obj.get("service_penalty"),
            "service_factor": obj.get("service_factor") if obj.get("service_factor") is not None else 1,
            "use_living_streets": obj.get("use_living_streets"),
            "use_ferry": obj.get("use_ferry") if obj.get("use_ferry") is not None else 0.5,
            "bicycle_type": obj.get("bicycle_type") if obj.get("bicycle_type") is not None else 'Hybrid',
            "cycling_speed": obj.get("cycling_speed"),
            "use_roads": obj.get("use_roads") if obj.get("use_roads") is not None else 0.5,
            "use_hills": obj.get("use_hills") if obj.get("use_hills") is not None else 0.5,
            "avoid_bad_surfaces": obj.get("avoid_bad_surfaces") if obj.get("avoid_bad_surfaces") is not None else 0.25,
            "bss_return_cost": obj.get("bss_return_cost") if obj.get("bss_return_cost") is not None else 120,
            "bss_return_penalty": obj.get("bss_return_penalty") if obj.get("bss_return_penalty") is not None else 0
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj




# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.1
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import stadiamaps
from stadiamaps.models.locate_node_all_of import LocateNodeAllOf  # noqa: E501
from stadiamaps.rest import ApiException

class TestLocateNodeAllOf(unittest.TestCase):
    """LocateNodeAllOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test LocateNodeAllOf
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LocateNodeAllOf`
        """
        model = stadiamaps.models.locate_node_all_of.LocateNodeAllOf()  # noqa: E501
        if include_optional :
            return LocateNodeAllOf(
                traffic_signal = True, 
                type = 'street_intersection', 
                node_id = stadiamaps.models.node_id.nodeId(
                    id = 56, 
                    value = 56, 
                    tile_id = 56, 
                    level = 56, ), 
                access = stadiamaps.models.access.access(
                    golf_cart = True, 
                    wheelchair = True, 
                    taxi = True, 
                    hov = True, 
                    truck = True, 
                    emergency = True, 
                    pedestrian = True, 
                    car = True, 
                    bus = True, 
                    bicycle = True, 
                    motorcycle = True, 
                    moped = True, ), 
                edge_count = 56, 
                administrative = stadiamaps.models.administrative.administrative(
                    iso_3166_1 = '', 
                    country = '', 
                    iso_3166_2 = '', 
                    state = '', ), 
                intersection_type = 'regular', 
                density = 56, 
                local_edge_count = 56, 
                mode_change = True
            )
        else :
            return LocateNodeAllOf(
        )
        """

    def testLocateNodeAllOf(self):
        """Test LocateNodeAllOf"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.4
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist
from stadiamaps.models.trace_attributes_base_response import TraceAttributesBaseResponse
from stadiamaps.models.valhalla_long_units import ValhallaLongUnits

class TraceAttributesResponseAllOf(BaseModel):
    """
    TraceAttributesResponseAllOf
    """
    id: Optional[StrictStr] = Field(None, description="An identifier to disambiguate requests (echoed by the server).")
    units: Optional[ValhallaLongUnits] = None
    alternate_paths: Optional[conlist(TraceAttributesBaseResponse)] = Field(None, description="Alternate paths, if any, that were not classified as the best match.")
    additional_properties: Dict[str, Any] = {}
    __properties = ["id", "units", "alternate_paths"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TraceAttributesResponseAllOf:
        """Create an instance of TraceAttributesResponseAllOf from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "additional_properties"
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in alternate_paths (list)
        _items = []
        if self.alternate_paths:
            for _item in self.alternate_paths:
                if _item:
                    _items.append(_item.to_dict())
            _dict['alternate_paths'] = _items
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TraceAttributesResponseAllOf:
        """Create an instance of TraceAttributesResponseAllOf from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return TraceAttributesResponseAllOf.parse_obj(obj)

        _obj = TraceAttributesResponseAllOf.parse_obj({
            "id": obj.get("id"),
            "units": obj.get("units"),
            "alternate_paths": [TraceAttributesBaseResponse.from_dict(_item) for _item in obj.get("alternate_paths")] if obj.get("alternate_paths") is not None else None
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj




# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.4
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr, conlist, validator
from stadiamaps.models.maneuver_sign import ManeuverSign
from stadiamaps.models.travel_mode import TravelMode

class RouteManeuver(BaseModel):
    """
    RouteManeuver
    """
    type: StrictInt = Field(..., description="The type of route maneuver.  | Code | Type                                | |------|-------------------------------------| | 0    | None                                | | 1    | Start                               | | 2    | Start right                         | | 3    | Start left                          | | 4    | Destination                         | | 5    | Destination right                   | | 6    | Destination left                    | | 7    | Becomes                             | | 8    | Continue                            | | 9    | Slight right                        | | 10   | Right                               | | 11   | Sharp right                         | | 12   | U-turn right                        | | 13   | U-turn left                         | | 14   | Sharp left                          | | 15   | Left                                | | 16   | Slight left                         | | 17   | Ramp straight                       | | 18   | Ramp right                          | | 19   | Ramp left                           | | 20   | Exit right                          | | 21   | Exit left                           | | 22   | Stay straight                       | | 23   | Stay right                          | | 24   | Stay left                           | | 25   | Merge                               | | 26   | Enter roundabout                    | | 27   | Exit roundabout                     | | 28   | Enter ferry                         | | 29   | Exit ferry                          | | 30   | Transit                             | | 31   | Transit transfer                    | | 32   | Transit remain on                   | | 33   | Transit connection start            | | 34   | Transit connection transfer         | | 35   | Transit connection destination      | | 36   | Post-transit connection destination | | 37   | Merge right                         | | 38   | Merge left                          | ")
    instruction: StrictStr = Field(..., description="The written maneuver instruction.")
    verbal_transition_alert_instruction: Optional[StrictStr] = Field(None, description="Text suitable for use as a verbal navigation alert.")
    verbal_pre_transition_instruction: Optional[StrictStr] = Field(None, description="Text suitable for use as a verbal navigation alert immediately prior to the maneuver transition.")
    verbal_post_transition_instruction: Optional[StrictStr] = Field(None, description="Text suitable for use as a verbal navigation alert immediately after to the maneuver transition.")
    street_names: Optional[conlist(StrictStr)] = Field(None, description="A list of street names that are consistent along the entire maneuver.")
    begin_street_names: Optional[conlist(StrictStr)] = Field(None, description="A list of street names at the beginning of the maneuver, if they are different from the names at the end.")
    time: Union[StrictFloat, StrictInt] = Field(..., description="The estimated time to complete the entire maneuver, in seconds.")
    length: Union[StrictFloat, StrictInt] = Field(..., description="The length of the maneuver, in `units`.")
    begin_shape_index: StrictInt = Field(..., description="The index into the list of shape points for the start of the maneuver.")
    end_shape_index: StrictInt = Field(..., description="The index into the list of shape points for the end of the maneuver.")
    toll: Optional[StrictBool] = Field(False, description="True any portion of the maneuver is subject to a toll.")
    rough: Optional[StrictBool] = Field(False, description="True any portion of the maneuver is unpaved or has portions of rough pavement.")
    gate: Optional[StrictBool] = Field(False, description="True if a gate is encountered in the course of this maneuver.")
    ferry: Optional[StrictBool] = Field(False, description="True if a ferry is encountered in the course of this maneuver.")
    sign: Optional[ManeuverSign] = None
    roundabout_exit_count: Optional[StrictInt] = Field(None, description="The exit number of the roundabout to take after entering.")
    depart_instruction: Optional[StrictInt] = Field(None, description="The written departure time instruction (typically used in a transit maneuver).")
    verbal_depart_instruction: Optional[StrictInt] = Field(None, description="Text suitable for use as a verbal departure time instruction (typically used in a transit maneuver).")
    arrive_instruction: Optional[StrictInt] = Field(None, description="The written arrival time instruction (typically used in a transit maneuver).")
    verbal_arrive_instruction: Optional[StrictInt] = Field(None, description="Text suitable for use as a verbal departure time instruction (typically used in a transit maneuver).")
    transit_info: Optional[Dict[str, Any]] = Field(None, description="Public transit info (not currently supported).")
    verbal_multi_cue: Optional[StrictBool] = Field(False, description="True if the `verbal_pre_transition_instruction` has been appended with the verbal instruction of the next maneuver.")
    travel_mode: TravelMode = Field(...)
    travel_type: StrictStr = Field(...)
    bss_maneuver_type: Optional[StrictStr] = Field(None, description="Describes a bike share action when using bikeshare routing.")
    additional_properties: Dict[str, Any] = {}
    __properties = ["type", "instruction", "verbal_transition_alert_instruction", "verbal_pre_transition_instruction", "verbal_post_transition_instruction", "street_names", "begin_street_names", "time", "length", "begin_shape_index", "end_shape_index", "toll", "rough", "gate", "ferry", "sign", "roundabout_exit_count", "depart_instruction", "verbal_depart_instruction", "arrive_instruction", "verbal_arrive_instruction", "transit_info", "verbal_multi_cue", "travel_mode", "travel_type", "bss_maneuver_type"]

    @validator('travel_type')
    def travel_type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('car', 'foot', 'road', 'tram', 'metro', 'rail', 'bus', 'ferry', 'cable_car', 'gondola', 'funicular'):
            raise ValueError("must be one of enum values ('car', 'foot', 'road', 'tram', 'metro', 'rail', 'bus', 'ferry', 'cable_car', 'gondola', 'funicular')")
        return value

    @validator('bss_maneuver_type')
    def bss_maneuver_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('NoneAction', 'RentBikeAtBikeShare', 'ReturnBikeAtBikeShare'):
            raise ValueError("must be one of enum values ('NoneAction', 'RentBikeAtBikeShare', 'ReturnBikeAtBikeShare')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RouteManeuver:
        """Create an instance of RouteManeuver from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "additional_properties"
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of sign
        if self.sign:
            _dict['sign'] = self.sign.to_dict()
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RouteManeuver:
        """Create an instance of RouteManeuver from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return RouteManeuver.parse_obj(obj)

        _obj = RouteManeuver.parse_obj({
            "type": obj.get("type"),
            "instruction": obj.get("instruction"),
            "verbal_transition_alert_instruction": obj.get("verbal_transition_alert_instruction"),
            "verbal_pre_transition_instruction": obj.get("verbal_pre_transition_instruction"),
            "verbal_post_transition_instruction": obj.get("verbal_post_transition_instruction"),
            "street_names": obj.get("street_names"),
            "begin_street_names": obj.get("begin_street_names"),
            "time": obj.get("time"),
            "length": obj.get("length"),
            "begin_shape_index": obj.get("begin_shape_index"),
            "end_shape_index": obj.get("end_shape_index"),
            "toll": obj.get("toll") if obj.get("toll") is not None else False,
            "rough": obj.get("rough") if obj.get("rough") is not None else False,
            "gate": obj.get("gate") if obj.get("gate") is not None else False,
            "ferry": obj.get("ferry") if obj.get("ferry") is not None else False,
            "sign": ManeuverSign.from_dict(obj.get("sign")) if obj.get("sign") is not None else None,
            "roundabout_exit_count": obj.get("roundabout_exit_count"),
            "depart_instruction": obj.get("depart_instruction"),
            "verbal_depart_instruction": obj.get("verbal_depart_instruction"),
            "arrive_instruction": obj.get("arrive_instruction"),
            "verbal_arrive_instruction": obj.get("verbal_arrive_instruction"),
            "transit_info": obj.get("transit_info"),
            "verbal_multi_cue": obj.get("verbal_multi_cue") if obj.get("verbal_multi_cue") is not None else False,
            "travel_mode": obj.get("travel_mode"),
            "travel_type": obj.get("travel_type"),
            "bss_maneuver_type": obj.get("bss_maneuver_type")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj




# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.4
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class PeliasSource(str, Enum):
    """
    Our database contains info from multiple sources. These identifiers can be used to either limit search results or to determine the relevance of a result.
    """

    """
    allowed enum values
    """
    OPENSTREETMAP = 'openstreetmap'
    OPENADDRESSES = 'openaddresses'
    WHOSONFIRST = 'whosonfirst'
    GEONAMES = 'geonames'

    @classmethod
    def from_json(cls, json_str: str) -> PeliasSource:
        """Create an instance of PeliasSource from a JSON string"""
        return PeliasSource(json.loads(json_str))





# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.1
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import stadiamaps
from stadiamaps.models.route_leg import RouteLeg  # noqa: E501
from stadiamaps.rest import ApiException

class TestRouteLeg(unittest.TestCase):
    """RouteLeg unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test RouteLeg
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RouteLeg`
        """
        model = stadiamaps.models.route_leg.RouteLeg()  # noqa: E501
        if include_optional :
            return RouteLeg(
                maneuvers = [
                    stadiamaps.models.route_maneuver.routeManeuver(
                        type = 56, 
                        instruction = '', 
                        verbal_transition_alert_instruction = '', 
                        verbal_pre_transition_instruction = '', 
                        verbal_post_transition_instruction = '', 
                        street_names = [
                            'A1'
                            ], 
                        begin_street_names = [
                            'A1'
                            ], 
                        time = 1.337, 
                        length = 1.337, 
                        begin_shape_index = 56, 
                        end_shape_index = 56, 
                        toll = True, 
                        rough = True, 
                        gate = True, 
                        ferry = True, 
                        sign = stadiamaps.models.maneuver_sign.maneuverSign(
                            exit_number_elements = [
                                stadiamaps.models.maneuver_sign_element.maneuverSignElement(
                                    text = '', 
                                    is_route_number = True, 
                                    consecutive_count = 56, )
                                ], 
                            exit_branch_elements = [
                                stadiamaps.models.maneuver_sign_element.maneuverSignElement(
                                    text = '', 
                                    is_route_number = True, 
                                    consecutive_count = 56, )
                                ], 
                            exit_toward_elements = [
                                
                                ], 
                            exit_name_elements = [
                                
                                ], ), 
                        roundabout_exit_count = 56, 
                        depart_instruction = 56, 
                        verbal_depart_instruction = 56, 
                        arrive_instruction = 56, 
                        verbal_arrive_instruction = 56, 
                        transit_info = { }, 
                        verbal_multi_cue = True, 
                        travel_mode = 'drive', 
                        travel_type = 'car', 
                        bss_maneuver_type = 'NoneAction', )
                    ], 
                shape = '', 
                summary = stadiamaps.models.route_summary.routeSummary(
                    time = 1.337, 
                    length = 1.337, 
                    min_lat = 1.337, 
                    max_lat = 1.337, 
                    min_lon = 1.337, 
                    max_lon = 1.337, )
            )
        else :
            return RouteLeg(
                maneuvers = [
                    stadiamaps.models.route_maneuver.routeManeuver(
                        type = 56, 
                        instruction = '', 
                        verbal_transition_alert_instruction = '', 
                        verbal_pre_transition_instruction = '', 
                        verbal_post_transition_instruction = '', 
                        street_names = [
                            'A1'
                            ], 
                        begin_street_names = [
                            'A1'
                            ], 
                        time = 1.337, 
                        length = 1.337, 
                        begin_shape_index = 56, 
                        end_shape_index = 56, 
                        toll = True, 
                        rough = True, 
                        gate = True, 
                        ferry = True, 
                        sign = stadiamaps.models.maneuver_sign.maneuverSign(
                            exit_number_elements = [
                                stadiamaps.models.maneuver_sign_element.maneuverSignElement(
                                    text = '', 
                                    is_route_number = True, 
                                    consecutive_count = 56, )
                                ], 
                            exit_branch_elements = [
                                stadiamaps.models.maneuver_sign_element.maneuverSignElement(
                                    text = '', 
                                    is_route_number = True, 
                                    consecutive_count = 56, )
                                ], 
                            exit_toward_elements = [
                                
                                ], 
                            exit_name_elements = [
                                
                                ], ), 
                        roundabout_exit_count = 56, 
                        depart_instruction = 56, 
                        verbal_depart_instruction = 56, 
                        arrive_instruction = 56, 
                        verbal_arrive_instruction = 56, 
                        transit_info = { }, 
                        verbal_multi_cue = True, 
                        travel_mode = 'drive', 
                        travel_type = 'car', 
                        bss_maneuver_type = 'NoneAction', )
                    ],
                shape = '',
                summary = stadiamaps.models.route_summary.routeSummary(
                    time = 1.337, 
                    length = 1.337, 
                    min_lat = 1.337, 
                    max_lat = 1.337, 
                    min_lon = 1.337, 
                    max_lon = 1.337, ),
        )
        """

    def testRouteLeg(self):
        """Test RouteLeg"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.1
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import stadiamaps
from stadiamaps.models.trace_attributes_base_response import TraceAttributesBaseResponse  # noqa: E501
from stadiamaps.rest import ApiException

class TestTraceAttributesBaseResponse(unittest.TestCase):
    """TraceAttributesBaseResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TraceAttributesBaseResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TraceAttributesBaseResponse`
        """
        model = stadiamaps.models.trace_attributes_base_response.TraceAttributesBaseResponse()  # noqa: E501
        if include_optional :
            return TraceAttributesBaseResponse(
                edges = [
                    stadiamaps.models.trace_edge.traceEdge(
                        names = [
                            ''
                            ], 
                        length = 1.337, 
                        speed = 56, 
                        road_class = 'motorway', 
                        begin_heading = 56, 
                        end_heading = 56, 
                        begin_shape_index = 56, 
                        end_shape_index = 56, 
                        traversability = 'forward', 
                        use = 'road', 
                        toll = True, 
                        unpaved = True, 
                        tunnel = True, 
                        bridge = True, 
                        roundabout = True, 
                        internal_intersection = True, 
                        drive_on_right = True, 
                        surface = 'paved_smooth', 
                        sign = stadiamaps.models.edge_sign.edgeSign(
                            exit_number = [
                                '91B'
                                ], 
                            exit_branch = [
                                'I 95 North'
                                ], 
                            exit_toward = [
                                'New York'
                                ], 
                            exit_name = [
                                'Gettysburg Pike'
                                ], ), 
                        travel_mode = 'drive', 
                        vehicle_type = 'car', 
                        pedestrian_type = 'foot', 
                        bicycle_type = 'road', 
                        transit_type = 'tram', 
                        id = 56, 
                        way_id = 56, 
                        weighted_grade = 1.337, 
                        max_upward_grade = 56, 
                        max_downward_grade = 56, 
                        mean_elevation = 56, 
                        lane_count = 56, 
                        cycle_lane = 'none', 
                        bicycle_network = 56, 
                        sac_scale = 56, 
                        sidewalk = 'left', 
                        density = 56, 
                        speed_limit = null, 
                        truck_speed = 56, 
                        truck_route = True, 
                        end_node = stadiamaps.models.end_node.endNode(
                            intersecting_edges = [
                                stadiamaps.models.intersecting_edge.intersectingEdge(
                                    begin_heading = 56, 
                                    from_edge_name_consistency = True, 
                                    to_edge_name_consistency = True, 
                                    driveability = 'forward', 
                                    cyclability = 'forward', 
                                    walkability = 'forward', )
                                ], 
                            elapsed_time = 1.337, 
                            admin_index = 56, 
                            type = 'street_intersection', 
                            fork = True, 
                            time_zone = 'America/New_York', ), )
                    ], 
                admins = [
                    stadiamaps.models.admin_region.adminRegion(
                        country_code = '', 
                        country_text = '', 
                        state_code = '', 
                        state_text = '', )
                    ], 
                matched_points = [
                    stadiamaps.models.matched_point.matchedPoint(
                        lat = 1.337, 
                        lon = 1.337, 
                        type = 'unmatched', 
                        edge_index = 56, 
                        begin_route_discontinuity = True, 
                        end_route_discontinuity = True, 
                        distance_along_edge = 1.337, 
                        distance_from_trace_point = 1.337, )
                    ], 
                osm_changeset = 56, 
                shape = '', 
                confidence_score = 0
            )
        else :
            return TraceAttributesBaseResponse(
        )
        """

    def testTraceAttributesBaseResponse(self):
        """Test TraceAttributesBaseResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.1
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import stadiamaps
from stadiamaps.api.routing_api import RoutingApi  # noqa: E501
from stadiamaps.rest import ApiException


class TestRoutingApi(unittest.TestCase):
    """RoutingApi unit test stubs"""

    def setUp(self):
        self.api = stadiamaps.api.routing_api.RoutingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_isochrone(self):
        """Test case for isochrone

        Calculate areas of equal travel time from a location.  # noqa: E501
        """
        pass

    def test_map_match(self):
        """Test case for map_match

        Match a recorded route to the road network.  # noqa: E501
        """
        pass

    def test_nearest_roads(self):
        """Test case for nearest_roads

        Find the nearest roads to the set of input locations.  # noqa: E501
        """
        pass

    def test_optimized_route(self):
        """Test case for optimized_route

        Calculate an optimized route between a known start and end point.  # noqa: E501
        """
        pass

    def test_route(self):
        """Test case for route

        Get turn by turn routing instructions between two or more locations.  # noqa: E501
        """
        pass

    def test_time_distance_matrix(self):
        """Test case for time_distance_matrix

        Calculate a time distance matrix for a grid of start and end points.  # noqa: E501
        """
        pass

    def test_trace_attributes(self):
        """Test case for trace_attributes

        Trace the attributes of roads visited on a route.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
